@@ -4,3 +4,5 @@ from . import invoice
 from . import offer
 from . import project
 from . import user
+from . import contact
+from . import deal
