@@ -12,7 +12,7 @@ def project(ctx):
 @click.option("-p", "--page", help="page number", type=int, default=1)
 @click.option("--include-archived", help="include archived projects", is_flag=True)
 @click.option("--include-company", help="include whole company", is_flag=True)
-@click.option('-a', "--retrieve-all", help="loops over the whole list", is_flag=True)
+@click.option('-a', "--retrieve-all", help="Retrieve all objects from the system (ignores page option)", is_flag=True)
 def getlist(ctx, page, include_archived, include_company, retrieve_all):
     moco = ctx.obj["moco"]
     formatter = ctx.obj["format"]
@@ -46,6 +46,11 @@ def getlist(ctx, page, include_archived, include_company, retrieve_all):
         formatter.format_list(items_list.items)
 
 @project.command()
+@click.argument("project-id", type=int)
 @click.pass_context
-def get(ctx):
-    pass
+def get(ctx, project_id):
+    formatter = ctx.obj["format"]
+    moco = ctx.obj["moco"]
+
+    company_obj = moco.Project.get(project_id)
+    formatter.format_single(company_obj.data)
