@@ -27,3 +27,9 @@ class TestCliMain(BaseCliTest):
 
     def test_offer_in_company_list(self):
         assert "offer" in cli.main.commands
+
+    def test_contact_in_commands_list(self):
+        assert "contact" in cli.main.commands
+
+    def test_deal_in_commands_list(self):
+        assert "deal" in cli.main.commands
